{
    // array die alle mogelijke cijfers van een kaart bevat.  Naast de cijfers is er ook nog J(oker), Q(ueen), K(ing) en A(ce)
    const cardNumbers = [`2`, `3`, `4`, `5`, `6`, `7`, `8`, `9`, `10`, `J`, `Q`, `K`, `A`];
    // array die alle mogelijke soorten bevat: Clubs (klaveren), Diamonds (ruiten), Hearts (harten) en Spades (schoppen)
    const cardSuits = [`C`, `D`, `H`, `S`];

    const sortCardsByNumber = (a, b) => {
        if (cardNumbers.indexOf(getCardNumber(a)) < cardNumbers.indexOf(getCardNumber(b))){
            return -1;
        }else{
            return 1;
        }
    };

    // functie die een getal aanmaakt tussen 0 en het maximum waarbij het maximum niet is inbegrepen
    // Zie: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Math/random
    const getRandomNumber = (max) => {
        return Math.floor(Math.random() * Math.floor(max));
    }

    // functie om het nummer van een kaart terug te geven
    const getCardNumber = card => card.split(`-`)[0];

    // functie om de suit van de kaart terug te geven
    const getCardSuit = card => card.split(`-`)[1];

    const pickRandomCard = () => {
        // kies een willekeurig element uit de array met nummers
        const number = cardNumbers[getRandomNumber(cardNumbers.length)];
        // kies een willekeurig element uit de array met soorten
        const suit = cardSuits[getRandomNumber(cardSuits.length)];
        // geef de combinatie terug. Dit matcht met de bestandsnaam van de afbeelding 
        return `${number}-${suit}`;
    }

    const getRandomCards = amount => {
        // maak een lege array, deze zal uiteindelijk evenveel kaarten bevatten als opgegeven in amount
        const cards = [];
        // zolang de array minder kaarten heeft dan gevraagd wordt onderstaande uitgevoerd.
        while (cards.length < amount) {
            // haal een random kaart op
            const card = pickRandomCard();
            // controleer of deze kaart al in de array zit, voeg enkel toe indien niet
            if (!cards.includes(card)) {
                cards.push(card);
            }
        }
        // geef de array met gekozen kaarten terug
        return cards.sort(sortCardsByNumber);
    };

    const showCards = pickedCards => {
        // selecteer het element waar de kaarten aan zullen toegevoegd worden
        const $table = document.querySelector(`.game-table`);
        // gebruik de combinatie van map() en join() om <li> elementen aan te maken die de juiste afbeelding bevatten
        $table.innerHTML = pickedCards.map(card => `<li><img src="assets/img/${card}.jpg" alt="card" width="130" height="199"></li>`).join(``);
    };

    const checkIdenitcalNumbers = (pickedCards, amount) => {
        // array waar alle identieke kaarten opgeslaan worden
        const identicals = [];
        // alle mogelijke kaartnummers overlopen
        cardNumbers.forEach(cardNumber => {
            let occurence = 0;
            // alle gekozen kaarten overlopen.  De variabele occurence optellen als de kaart voorkomt
            pickedCards.forEach(card => {
                if (cardNumber === getCardNumber(card)) {
                    occurence++;
                }
            });
            // voor elk item binnen cardNumbers kijken of de kaart evenveel voorkomt als gevraagd in amount
            // indien ja: opslaan in de array
            if (occurence === amount) {
                identicals.push(cardNumber);
            }
        });
        return identicals;
    };

    const checkAllIdenticalSuit = pickedCards => {
        // check de suit van de eerste kaart
        const firstSuit = getCardSuit(pickedCards[0]);
        return pickedCards.every(card => getCardSuit(card) === firstSuit);


        // ALTERNATIEF: iets meer werk
        // loop over alle andere kaarten en check of de suit gelijk is aan de eerste kaart
        // indien dit 1 keer niet het geval is geeft de functie false terug
        // als dit altijd het geval was geeft de functie op het einde true terug
        /*for(let i=1; i<pickedCards.length;i++){
            if (getCardSuit(pickedCards[i]) !== firstSuit) {
                return false;
            }
        }
        return true;*/
    };

    const checkFiveInARow = (pickedCards, highestPossible) => {
        let numberValues;
        // als de paramter highestPossible op true staat (controle voor royal flush)
        // kunnen de waarden al ingevuld worden.  De kaarten moeten immers 10 J Q K A zijn
        if(highestPossible){
            numberValues = `10JQKA`;
        }else{
            // de array van de kaarten omzetten naar een string met enkel de kaartnummers  
            numberValues = pickedCards.map(card => getCardNumber(card)).join(``);
        }
        // de kaarten zijn altijd gesorteerd.  
        // controleer wat de positie van de eerste kaart is in de array cardNumbers
        const first = cardNumbers.indexOf(getCardNumber(pickedCards[0]));
    
        // selecteer 5 elementen uit de array cardNumbers te beginnen op de positie die overeenkomt met de positie van de eerste kaart
        // zet deze array om naar een string
        const checkSum = cardNumbers.slice(first,first+5).join(``);
    
        // controleer of de nummers van de gekozen kaarten matchen met de 5 elementen uit cardNumbers
        // indien ja: je hebt 5 opeenvolgende kaarten
        if(numberValues === checkSum){
           return true;
        }else{
            return false;
        }
    };

    const checkForCombinations = pickedCards => {
        // rules = https://www.slideshare.net/DrorGal/the-winning-hands-of-texas-holdem
        // Royal flush = 5 hoogste kaarten van dezelfde soort op een rij
        if (checkFiveInARow(pickedCards, true) && checkAllIdenticalSuit(pickedCards)){
            return `Wow, you have a royal flush`;
        }

        // Straight flush = 5 kaarten op een rij van dezelfde soort
        if(checkFiveInARow(pickedCards,false) && checkAllIdenticalSuit(pickedCards)){
            return `Great, you have a straight flush`
        }

        // Four of a kind = 4 dezelfde kaarten
        if (checkIdenitcalNumbers(pickedCards, 4).length === 1) {
            return `Cool, you have four of a kind`;
        }

        //  Full house = 3 dezelfde kaarten en 2 dezelfde kaarten
        if (checkIdenitcalNumbers(pickedCards, 3).length === 1 && checkIdenitcalNumbers(pickedCards, 2).length === 1) {
            return `Nice, you have a full house`;
        }

        // Flush = 5 kaarten van hetzelfde type
        if (checkAllIdenticalSuit(pickedCards)) {
            return `All the same: you have a flush`
        }

        // Straight = 5 kaarten op een rij
        if(checkFiveInARow(pickedCards, false)){
            return `All in a row: you have a straight`;
        }

        // Three of a kind = 3 dezelfde kaarten
        if (checkIdenitcalNumbers(pickedCards, 3).length === 1) {
            return `Ok, you have three of a kind`;
        }

        // Two pair = 2 x 2 dezelfde kaarten
        if (checkIdenitcalNumbers(pickedCards, 2).length === 2) {
            return `Ok, you have two pairs`;
        }

        // Pair = 2 dezelfde kaarten
        if (checkIdenitcalNumbers(pickedCards, 2).length === 1) {
            return `Hmmm, you only have a pair`;
        } 
    
        return `Bummer, you have nothing`;
    };

    const init = () => {
        // Selecteer 5 unieke kaarten.  
        const pickedCards = getRandomCards(5);
        // gebruik deze array om combinaties die zelden zijn (zoals royal flush) te testen
         //const pickedCards = [`10-H`, `J-H`, `Q-H`, `K-H`, `A-H`]

        // Toon deze kaarten op het scherm
        showCards(pickedCards);

        // Controleer welke combinatie je hebt
        const $message = document.querySelector(`.message`);
        $message.textContent = checkForCombinations(pickedCards);
    };

    init();
}
